from .functions import *
from .routes.llm_storage_routes import llm_bp
from .routes.chat_routes import chat_bp
from .routes.search_routes import search_bp
from .routes.upload_routes import upload_bp
from .routes.worker_routes import worker_bp
from .routes.prompt_routes import prompt_bp
from .routes.phone_brick_routes import phone_brick_bp
from .routes.discord_routes import discord_bp

